@@ -1,28 +1,24 @@
 require 'spec_helper'
 
 describe 'glance::glare' do
-
+  let :pre_condition do
+    "class {'::glance::glare::authtoken':
+      password => 'ChangeMe',
+    }"
+  end
   let :default_params do
     {
       :bind_host                => '0.0.0.0',
       :bind_port                => '9494',
-      :auth_type                => 'keystone',
+      :auth_strategy            => 'keystone',
       :enabled                  => true,
       :manage_service           => true,
       :backlog                  => '4096',
       :workers                  => '7',
-      :keystone_tenant          => 'services',
-      :keystone_user            => 'glance',
-      :keystone_password        => 'ChangeMe',
-      :token_cache_time         => '<SERVICE DEFAULT>',
-      :memcached_servers        => '<SERVICE DEFAULT>',
       :stores                   => false,
       :default_store            => false,
       :os_region_name           => 'RegionOne',
-      :signing_dir              => '<SERVICE DEFAULT>',
       :pipeline                 => 'keystone',
-      :auth_uri                 => 'http://127.0.0.1:5000/',
-      :identity_uri             => 'http://127.0.0.1:35357/',
     }
   end
 
@@ -31,23 +27,16 @@ describe 'glance::glare' do
      {
         :bind_host                => '127.0.0.1',
         :bind_port                => '9222',
-        :auth_type                => 'not_keystone',
+        :auth_strategy                => 'not_keystone',
         :enabled                  => false,
         :backlog                  => '4095',
         :workers                  => '5',
-        :keystone_tenant          => 'admin2',
-        :keystone_user            => 'admin2',
-        :keystone_password        => 'ChangeMe2',
-        :token_cache_time         => '300',
         :os_region_name           => 'RegionOne2',
-        :signing_dir              => '/path/to/dir',
         :pipeline                 => 'keystone2',
-        :auth_uri                 => 'http://127.0.0.1:5000/v2.0',
-        :identity_uri             => 'http://127.0.0.1:35357/v2.0',
       }
     ].each do |param_set|
 
-      describe "when #{param_set == {:keystone_password => 'ChangeMe'} ? "using default" : "specifying"} class parameters" do
+      describe "when not using default class parameters" do
 
         let :param_hash do
           default_params.merge(param_set)
@@ -95,14 +84,9 @@ describe 'glance::glare' do
           is_expected.to contain_glance_glare_config('DEFAULT/key_file').with_value('<SERVICE DEFAULT>')
         end
 
-        it 'is_expected.to configure itself for keystone if that is the auth_type' do
-          if params[:auth_type] == 'keystone'
+        it 'is_expected.to configure itself for keystone if that is the auth_strategy' do
+          if params[:auth_strategy] == 'keystone'
             is_expected.to contain('paste_deploy/flavor').with_value('keystone+cachemanagement')
-            is_expected.to contain_glance_glare_config('keystone_authtoken/memcached_servers').with_value(param_hash[:memcached_servers])
-            ['admin_tenant_name', 'admin_user', 'admin_password', 'token_cache_time', 'signing_dir', 'auth_uri', 'identity_uri'].each do |config|
-              is_expected.to contain_glance_glare_config("keystone_authtoken/#{config}").with_value(param_hash[config.intern])
-            end
-            is_expected.to contain_glance_glare_config('keystone_authtoken/admin_password').with_value(param_hash[:keystone_password]).with_secret(true)
           end
         end
       end
@@ -112,7 +96,6 @@ describe 'glance::glare' do
     describe 'with disabled service managing' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
           :manage_service => false,
           :enabled        => false,
         }
@@ -130,8 +113,7 @@ describe 'glance::glare' do
     describe 'with overridden pipeline' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
-          :pipeline          => 'something',
+          :pipeline => 'something',
         }
       end
 
@@ -141,8 +123,7 @@ describe 'glance::glare' do
     describe 'with blank pipeline' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
-          :pipeline          => '',
+          :pipeline => '',
         }
       end
 
@@ -159,8 +140,7 @@ describe 'glance::glare' do
       describe "with pipeline incorrect value #{pipeline}" do
         let :params do
           {
-            :keystone_password => 'ChangeMe',
-            :pipeline          => pipeline
+            :pipeline => pipeline
           }
         end
 
@@ -250,7 +230,7 @@ describe 'glance::glare' do
       it { is_expected.to contain_glance_glare_config('glance_store/default_store').with_value('glance.store.filesystem.Store') }
       it { is_expected.to contain_glance_glare_config('glance_store/stores').with_value('glance.store.filesystem.Store') }
     end
-  end
+end
 
   shared_examples_for 'glance::glare Debian' do
     let(:params) { default_params }
